library ieee;
use ieee.std_logic_1164.all;

use work.rs_test_interface.all;

entity rs_tb is
end entity rs_tb;

architecture a of rs_tb is

component TxUnit is
  port (
     Clk    	: in  Std_Logic;  -- Clock signal
     Reset_n  	: in  Std_Logic;  -- Reset input, active low
     Load   	: in  Std_Logic;  -- Load transmit data
     TxD    	: out Std_Logic;  -- RS-232 data output
     TRegE_n  	: out Std_Logic;  -- Tx register empty, active low
     TBufE_n  	: out Std_Logic;  -- Tx buffer empty, active low
     DataO  	: in  Std_Logic_Vector(7 downto 0)); 
end component;

signal clk: std_logic := '0';
signal reset_n: std_logic;
signal load: std_logic;
signal txd: std_logic;
signal buf_empty_n: std_logic;
signal data: std_logic_vector (7 downto 0);
signal treg_empty_n: std_logic;
begin

tx: TxUnit port map (
       Clk => clk,
       Reset_n => reset_n,
       Load => load,
       TxD => txd,
       TRegE_n => treg_empty_n,
       TBufE_n => buf_empty_n,
       DataO => data
    );

clkgen: process
   begin
      wait for 1000 ms / 9600 / 2;
      clk <= not clk;
   end process;

test: process
   begin
      reset_n <= '0';
      load <= '0';
      wait until clk'event and clk='1';
      reset_n <= '1';
      PROC_RS_WRITE_BYTE (x"AA", buf_empty_n, clk, load, data);
      PROC_RS_WRITE_BYTE (x"66", buf_empty_n, clk, load, data);
      wait until treg_empty_n = '0' and buf_empty_n = '0';
      assert false
         report "Simulation finished"
         severity failure;
end process;

end architecture a;
